from pydantic_settings import BaseSettings
from pathlib import Path
import os

class Settings(BaseSettings):
    PROJECT_NAME: str = "Crypto P2P Trading Platform"
    SERVER_HOST: str = os.getenv("SERVER_HOST", "http://localhost:8000")
    
    SECRET_KEY: str = os.getenv("SECRET_KEY", "crypto-p2p-super-secret-key-change-in-production")
    ALGORITHM: str = "HS256"
    ACCESS_TOKEN_EXPIRE_MINUTES: int = 60 * 24 * 8
    
    DB_DIR: Path = Path("/app/storage/db")
    SQLALCHEMY_DATABASE_URL: str = f"sqlite:///{DB_DIR}/db.sqlite"
    
    PAYMENT_PROVIDER_API_URL: str = os.getenv("PAYMENT_PROVIDER_API_URL", "")
    PAYMENT_PROVIDER_API_KEY: str = os.getenv("PAYMENT_PROVIDER_API_KEY", "")
    
    class Config:
        env_file = ".env"

settings = Settings()