from sqlalchemy import Column, Integer, String, Boolean, DateTime
from sqlalchemy.orm import relationship
from sqlalchemy.sql import func
from app.db.base import Base

class User(Base):
    __tablename__ = "users"
    
    id = Column(Integer, primary_key=True, index=True)
    email = Column(String, unique=True, index=True, nullable=False)
    username = Column(String, unique=True, index=True, nullable=False)
    hashed_password = Column(String, nullable=False)
    is_active = Column(Boolean, default=True)
    is_verified = Column(Boolean, default=False)
    created_at = Column(DateTime, server_default=func.now())
    updated_at = Column(DateTime, server_default=func.now(), onupdate=func.now())
    
    # Relationships
    wallets = relationship("Wallet", back_populates="user")
    advertisements = relationship("Advertisement", back_populates="user")
    buy_orders = relationship("Order", foreign_keys="Order.buyer_id", back_populates="buyer")
    sell_orders = relationship("Order", foreign_keys="Order.seller_id", back_populates="seller")