from sqlalchemy import Column, Integer, Float, DateTime, ForeignKey, Index
from sqlalchemy.orm import relationship
from sqlalchemy.sql import func
from app.db.base import Base

class Wallet(Base):
    __tablename__ = "wallets"
    
    id = Column(Integer, primary_key=True, index=True)
    user_id = Column(Integer, ForeignKey("users.id"), nullable=False)
    cryptocurrency_id = Column(Integer, ForeignKey("cryptocurrencies.id"), nullable=False)
    available_balance = Column(Float, default=0.0)
    locked_balance = Column(Float, default=0.0)  # Funds locked in active orders
    created_at = Column(DateTime, server_default=func.now())
    updated_at = Column(DateTime, server_default=func.now(), onupdate=func.now())
    
    # Relationships
    user = relationship("User", back_populates="wallets")
    cryptocurrency = relationship("Cryptocurrency", back_populates="wallets")
    
    @property
    def total_balance(self):
        return self.available_balance + self.locked_balance
    
    # Ensure one wallet per user per cryptocurrency
    __table_args__ = (Index('ix_user_crypto', 'user_id', 'cryptocurrency_id', unique=True),)