from typing import Optional
from pydantic import BaseModel
from datetime import datetime


class CryptocurrencyBase(BaseModel):
    symbol: str
    name: str
    is_active: Optional[bool] = True
    min_trade_amount: Optional[float] = 0.00001
    max_trade_amount: Optional[float] = 1000000.0
    precision: Optional[int] = 8


class CryptocurrencyCreate(CryptocurrencyBase):
    pass


class CryptocurrencyUpdate(CryptocurrencyBase):
    symbol: Optional[str] = None
    name: Optional[str] = None


class CryptocurrencyInDBBase(CryptocurrencyBase):
    id: Optional[int] = None
    created_at: Optional[datetime] = None

    class Config:
        from_attributes = True


class Cryptocurrency(CryptocurrencyInDBBase):
    pass